Range

Enum Range 

pub enum Range {
    Int {
        first: u64,
        last: Option<u64>,
    },
    Suffix {
        length: u64,
    },
}
HTTP Range header

Amazon S3 doesn’t support retrieving multiple ranges of data per GET request.

See https://www.rfc-editor.org/rfc/rfc9110.html#section-14.1.2

Variants



Int

Int range in bytes. This range is inclusive.

See https://www.rfc-editor.org/rfc/rfc9110.html#rule.int-range

Fields

first: u64

first position

last: Option<u64>

last position



Suffix

Fields

length: u64

suffix length

Implementations

Source

impl Range

pub fn parse(header: &str) -> Result<Self, ParseRangeError>

Parses Range from header

Errors

Returns an error if the header is invalid

pub fn to_header_string(&self) -> String

pub fn check(&self, full_length: u64) -> Result<Range<u64>, RangeNotSatisfiable>

Checks if the range is satisfiable according to RFC9110.

Errors

Returns an error if the range is not satisfiable