pub struct Bucket {
pub bucket_region: Option<BucketRegion>,
pub creation_date: Option<CreationDate>,
pub name: Option<BucketName>,
}Expand description
In terms of implementation, a Bucket is a resource.
Fields
bucket_region: Option<BucketRegion>
BucketRegion indicates the Amazon Web Services region where the bucket is located. If the
request contains at least one valid parameter, it is included in the response.
creation_date: Option<CreationDate>Date the bucket was created. This date can change when making changes to your bucket, such as editing its bucket policy.
name: Option<BucketName>The name of the bucket.