pub struct DeleteBucketLifecycleInput {
pub bucket: BucketName,
pub expected_bucket_owner: Option<AccountId>,
}Fields
bucket: BucketNameThe bucket name of the lifecycle to delete.
expected_bucket_owner: Option<AccountId>The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code 403 Forbidden (access denied).
This parameter applies to general purpose buckets only. It is not supported for directory bucket lifecycle configurations.
Implementations