pub struct DeleteObjectOutput {
pub delete_marker: Option<DeleteMarker>,
pub request_charged: Option<RequestCharged>,
pub version_id: Option<ObjectVersionId>,
}Fields
delete_marker: Option<DeleteMarker>Indicates whether the specified object version that was permanently deleted was (true) or was not (false) a delete marker before deletion. In a simple DELETE, this header indicates whether (true) or not (false) the current version of the object is a delete marker. To learn more about delete markers, see Working with delete markers.
This functionality is not supported for directory buckets.
request_charged: Option<RequestCharged>version_id: Option<ObjectVersionId>Returns the version ID of the delete marker created as a result of the DELETE operation.
This functionality is not supported for directory buckets.