Struct s3s::dto::GetBucketLifecycleConfigurationInput
source · pub struct GetBucketLifecycleConfigurationInput {
pub bucket: BucketName,
pub expected_bucket_owner: Option<AccountId>,
}Fields
bucket: BucketNameThe name of the bucket for which to get the lifecycle information.
expected_bucket_owner: Option<AccountId>The account ID of the expected bucket owner. If the bucket is owned by a different account, the request fails with the HTTP status code 403 Forbidden (access denied).