pub struct GetBucketOwnershipControlsInput {
pub bucket: BucketName,
pub expected_bucket_owner: Option<AccountId>,
}Fields
bucket: BucketNameThe name of the Amazon S3 bucket whose OwnershipControls you want to retrieve.
expected_bucket_owner: Option<AccountId>The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code 403 Forbidden (access denied).
Implementations