HeadBucketOutput

Struct HeadBucketOutput 

pub struct HeadBucketOutput {
    pub access_point_alias: Option<AccessPointAlias>,
    pub bucket_location_name: Option<BucketLocationName>,
    pub bucket_location_type: Option<LocationType>,
    pub bucket_region: Option<Region>,
}

Fields

access_point_alias: Option<AccessPointAlias>

Indicates whether the bucket name used in the request is an access point alias.

For directory buckets, the value of this field is false.

bucket_location_name: Option<BucketLocationName>

The name of the location where the bucket will be created.

For directory buckets, the Zone ID of the Availability Zone or the Local Zone where the bucket is created. An example Zone ID value for an Availability Zone is usw2-az1.

This functionality is only supported by directory buckets.

bucket_location_type: Option<LocationType>

The type of location where the bucket is created.

This functionality is only supported by directory buckets.

bucket_region: Option<Region>

The Region that the bucket is located.