pub struct HeadObjectOutput {Show 37 fields
pub accept_ranges: Option<AcceptRanges>,
pub archive_status: Option<ArchiveStatus>,
pub bucket_key_enabled: Option<BucketKeyEnabled>,
pub cache_control: Option<CacheControl>,
pub checksum_crc32: Option<ChecksumCRC32>,
pub checksum_crc32c: Option<ChecksumCRC32C>,
pub checksum_crc64nvme: Option<ChecksumCRC64NVME>,
pub checksum_sha1: Option<ChecksumSHA1>,
pub checksum_sha256: Option<ChecksumSHA256>,
pub checksum_type: Option<ChecksumType>,
pub content_disposition: Option<ContentDisposition>,
pub content_encoding: Option<ContentEncoding>,
pub content_language: Option<ContentLanguage>,
pub content_length: Option<ContentLength>,
pub content_range: Option<ContentRange>,
pub content_type: Option<ContentType>,
pub delete_marker: Option<DeleteMarker>,
pub e_tag: Option<ETag>,
pub expiration: Option<Expiration>,
pub expires: Option<Expires>,
pub last_modified: Option<LastModified>,
pub metadata: Option<Metadata>,
pub missing_meta: Option<MissingMeta>,
pub object_lock_legal_hold_status: Option<ObjectLockLegalHoldStatus>,
pub object_lock_mode: Option<ObjectLockMode>,
pub object_lock_retain_until_date: Option<ObjectLockRetainUntilDate>,
pub parts_count: Option<PartsCount>,
pub replication_status: Option<ReplicationStatus>,
pub request_charged: Option<RequestCharged>,
pub restore: Option<Restore>,
pub sse_customer_algorithm: Option<SSECustomerAlgorithm>,
pub sse_customer_key_md5: Option<SSECustomerKeyMD5>,
pub ssekms_key_id: Option<SSEKMSKeyId>,
pub server_side_encryption: Option<ServerSideEncryption>,
pub storage_class: Option<StorageClass>,
pub version_id: Option<ObjectVersionId>,
pub website_redirect_location: Option<WebsiteRedirectLocation>,
}Fields
accept_ranges: Option<AcceptRanges>Indicates that a range of bytes was specified.
archive_status: Option<ArchiveStatus>The archive state of the head object.
This functionality is not supported for directory buckets.
bucket_key_enabled: Option<BucketKeyEnabled>Indicates whether the object uses an S3 Bucket Key for server-side encryption with Key Management Service (KMS) keys (SSE-KMS).
cache_control: Option<CacheControl>Specifies caching behavior along the request/reply chain.
checksum_crc32: Option<ChecksumCRC32>The Base64 encoded, 32-bit CRC32 checksum of the object. This checksum is only be present if the checksum was uploaded
with the object. When you use an API operation on an object that was uploaded using multipart uploads, this value may not be a direct checksum value of the full object. Instead, it's a calculation based on the checksum values of each individual part. For more information about how checksums are calculated
with multipart uploads, see
Checking object integrity in the Amazon S3 User Guide.
checksum_crc32c: Option<ChecksumCRC32C>The Base64 encoded, 32-bit CRC32C checksum of the object. This checksum is only present if the checksum was uploaded
with the object. When you use an API operation on an object that was uploaded using multipart uploads, this value may not be a direct checksum value of the full object. Instead, it's a calculation based on the checksum values of each individual part. For more information about how checksums are calculated
with multipart uploads, see
Checking object integrity in the Amazon S3 User Guide.
checksum_crc64nvme: Option<ChecksumCRC64NVME>The Base64 encoded, 64-bit CRC64NVME checksum of the object. For more
information, see Checking object integrity
in the Amazon S3 User Guide.
checksum_sha1: Option<ChecksumSHA1>The Base64 encoded, 160-bit SHA1 digest of the object. This will only be present if the object was uploaded
with the object. When you use the API operation on an object that was uploaded using multipart uploads, this value may not be a direct checksum value of the full object. Instead, it's a calculation based on the checksum values of each individual part. For more information about how checksums are calculated
with multipart uploads, see
Checking object integrity in the Amazon S3 User Guide.
checksum_sha256: Option<ChecksumSHA256>The Base64 encoded, 256-bit SHA256 digest of the object. This will only be present if the object was uploaded
with the object. When you use an API operation on an object that was uploaded using multipart uploads, this value may not be a direct checksum value of the full object. Instead, it's a calculation based on the checksum values of each individual part. For more information about how checksums are calculated
with multipart uploads, see
Checking object integrity in the Amazon S3 User Guide.
checksum_type: Option<ChecksumType>The checksum type, which determines how part-level checksums are combined to create an
object-level checksum for multipart objects. You can use this header response to verify
that the checksum type that is received is the same checksum type that was specified in
CreateMultipartUpload request. For more
information, see Checking object integrity
in the Amazon S3 User Guide.
content_disposition: Option<ContentDisposition>Specifies presentational information for the object.
content_encoding: Option<ContentEncoding>Indicates what content encodings have been applied to the object and thus what decoding mechanisms must be applied to obtain the media-type referenced by the Content-Type header field.
content_language: Option<ContentLanguage>The language the content is in.
content_length: Option<ContentLength>Size of the body in bytes.
content_range: Option<ContentRange>The portion of the object returned in the response for a GET request.
content_type: Option<ContentType>A standard MIME type describing the format of the object data.
delete_marker: Option<DeleteMarker>Specifies whether the object retrieved was (true) or was not (false) a Delete Marker. If false, this response header does not appear in the response.
This functionality is not supported for directory buckets.
e_tag: Option<ETag>An entity tag (ETag) is an opaque identifier assigned by a web server to a specific version of a resource found at a URL.
expiration: Option<Expiration>If the object expiration is configured (see
PutBucketLifecycleConfiguration
), the response includes this
header. It includes the expiry-date and rule-id key-value pairs
providing object expiration information. The value of the rule-id is
URL-encoded.
Object expiration information is not returned in directory buckets and this header returns the value "NotImplemented" in all responses for directory buckets.
expires: Option<Expires>The date and time at which the object is no longer cacheable.
last_modified: Option<LastModified>Date and time when the object was last modified.
metadata: Option<Metadata>A map of metadata to store with the object in S3.
missing_meta: Option<MissingMeta>This is set to the number of metadata entries not returned in x-amz-meta
headers. This can happen if you create metadata using an API like SOAP that supports more
flexible metadata than the REST API. For example, using SOAP, you can create metadata whose
values are not legal HTTP headers.
This functionality is not supported for directory buckets.
object_lock_legal_hold_status: Option<ObjectLockLegalHoldStatus>Specifies whether a legal hold is in effect for this object. This header is only
returned if the requester has the s3:GetObjectLegalHold permission. This
header is not returned if the specified version of this object has never had a legal hold
applied. For more information about S3 Object Lock, see Object Lock.
This functionality is not supported for directory buckets.
object_lock_mode: Option<ObjectLockMode>The Object Lock mode, if any, that's in effect for this object. This header is only
returned if the requester has the s3:GetObjectRetention permission. For more
information about S3 Object Lock, see Object Lock.
This functionality is not supported for directory buckets.
object_lock_retain_until_date: Option<ObjectLockRetainUntilDate>The date and time when the Object Lock retention period expires. This header is only
returned if the requester has the s3:GetObjectRetention permission.
This functionality is not supported for directory buckets.
parts_count: Option<PartsCount>The count of parts this object has. This value is only returned if you specify
partNumber in your request and the object was uploaded as a multipart
upload.
replication_status: Option<ReplicationStatus>Amazon S3 can return this header if your request involves a bucket that is either a source or a destination in a replication rule.
In replication, you have a source bucket on which you configure replication and
destination bucket or buckets where Amazon S3 stores object replicas. When you request an object
(GetObject) or object metadata (HeadObject) from these
buckets, Amazon S3 will return the x-amz-replication-status header in the response
as follows:
-
If requesting an object from the source bucket, Amazon S3 will return the
x-amz-replication-statusheader if the object in your request is eligible for replication.For example, suppose that in your replication configuration, you specify object prefix
TaxDocsrequesting Amazon S3 to replicate objects with key prefixTaxDocs. Any objects you upload with this key name prefix, for exampleTaxDocs/document1.pdf, are eligible for replication. For any object request with this key name prefix, Amazon S3 will return thex-amz-replication-statusheader with value PENDING, COMPLETED or FAILED indicating object replication status. -
If requesting an object from a destination bucket, Amazon S3 will return the
x-amz-replication-statusheader with value REPLICA if the object in your request is a replica that Amazon S3 created and there is no replica modification replication in progress. -
When replicating objects to multiple destination buckets, the
x-amz-replication-statusheader acts differently. The header of the source object will only return a value of COMPLETED when replication is successful to all destinations. The header will remain at value PENDING until replication has completed for all destinations. If one or more destinations fails replication the header will return FAILED.
For more information, see Replication.
This functionality is not supported for directory buckets.
request_charged: Option<RequestCharged>restore: Option<Restore>If the object is an archived object (an object whose storage class is GLACIER), the response includes this header if either the archive restoration is in progress (see RestoreObject or an archive copy is already restored.
If an archive copy is already restored, the header value indicates when Amazon S3 is scheduled to delete the object copy. For example:
x-amz-restore: ongoing-request="false", expiry-date="Fri, 21 Dec 2012 00:00:00
GMT"
If the object restoration is in progress, the header returns the value
ongoing-request="true".
For more information about archiving objects, see Transitioning Objects: General Considerations.
This functionality is not supported for directory buckets. Only the S3 Express One Zone storage class is supported by directory buckets to store objects.
sse_customer_algorithm: Option<SSECustomerAlgorithm>If server-side encryption with a customer-provided encryption key was requested, the response will include this header to confirm the encryption algorithm that's used.
This functionality is not supported for directory buckets.
sse_customer_key_md5: Option<SSECustomerKeyMD5>If server-side encryption with a customer-provided encryption key was requested, the response will include this header to provide the round-trip message integrity verification of the customer-provided encryption key.
This functionality is not supported for directory buckets.
ssekms_key_id: Option<SSEKMSKeyId>If present, indicates the ID of the KMS key that was used for object encryption.
server_side_encryption: Option<ServerSideEncryption>The server-side encryption algorithm used when you store this object in Amazon S3 (for
example, AES256, aws:kms, aws:kms:dsse).
storage_class: Option<StorageClass>Provides storage class information of the object. Amazon S3 returns this header for all objects except for S3 Standard storage class objects.
For more information, see Storage Classes.
Directory buckets - Only the S3 Express One Zone storage class is supported by directory buckets to store objects.
version_id: Option<ObjectVersionId>Version ID of the object.
This functionality is not supported for directory buckets.
website_redirect_location: Option<WebsiteRedirectLocation>If the bucket is configured as a website, redirects requests for this object to another object in the same bucket or to an external URL. Amazon S3 stores the value of this header in the object metadata.
This functionality is not supported for directory buckets.