LifecycleRuleFilter

Struct LifecycleRuleFilter 

pub struct LifecycleRuleFilter {
    pub and: Option<LifecycleRuleAndOperator>,
    pub cached_tags: CachedTags,
    pub object_size_greater_than: Option<ObjectSizeGreaterThanBytes>,
    pub object_size_less_than: Option<ObjectSizeLessThanBytes>,
    pub prefix: Option<Prefix>,
    pub tag: Option<Tag>,
}
The Filter is used to identify objects that a Lifecycle Rule applies to. A Filter can have exactly one of Prefix, Tag, ObjectSizeGreaterThan, ObjectSizeLessThan, or And specified. If the Filter element is left empty, the Lifecycle Rule applies to all objects in the bucket.

Fields

and: Option<LifecycleRuleAndOperator>cached_tags: CachedTagsobject_size_greater_than: Option<ObjectSizeGreaterThanBytes>

Minimum object size to which the rule applies.

object_size_less_than: Option<ObjectSizeLessThanBytes>

Maximum object size to which the rule applies.

prefix: Option<Prefix>

Prefix identifying one or more objects to which the rule applies.

Replacement must be made for object keys containing special characters (such as carriage returns) when using XML requests. For more information, see XML related object key constraints.

tag: Option<Tag>

This tag must exist in the object's tag set in order for the rule to apply.

This parameter applies to general purpose buckets only. It is not supported for directory bucket lifecycle configurations.

Implementations

Source

impl LifecycleRuleFilter

pub fn test_tags(&self, object_tags: &Map<String, String>) -> bool