pub struct NotificationConfiguration {
pub event_bridge_configuration: Option<EventBridgeConfiguration>,
pub lambda_function_configurations: Option<LambdaFunctionConfigurationList>,
pub queue_configurations: Option<QueueConfigurationList>,
pub topic_configurations: Option<TopicConfigurationList>,
}Expand description
A container for specifying the notification configuration of the bucket. If this element is empty, notifications are turned off for the bucket.
Fields
event_bridge_configuration: Option<EventBridgeConfiguration>Enables delivery of events to Amazon EventBridge.
lambda_function_configurations: Option<LambdaFunctionConfigurationList>Describes the Lambda functions to invoke and the events for which to invoke them.
queue_configurations: Option<QueueConfigurationList>The Amazon Simple Queue Service queues to publish messages to and the events for which to publish messages.
topic_configurations: Option<TopicConfigurationList>The topic to which notifications are sent and the events for which notifications are generated.