PutBucketTaggingInput

Struct PutBucketTaggingInput 

pub struct PutBucketTaggingInput {
    pub bucket: BucketName,
    pub checksum_algorithm: Option<ChecksumAlgorithm>,
    pub content_md5: Option<ContentMD5>,
    pub expected_bucket_owner: Option<AccountId>,
    pub tagging: Tagging,
}

Fields

bucket: BucketName

The bucket name.

checksum_algorithm: Option<ChecksumAlgorithm>

Indicates the algorithm used to create the checksum for the request when you use the SDK. This header will not provide any additional functionality if you don't use the SDK. When you send this header, there must be a corresponding x-amz-checksum or x-amz-trailer header sent. Otherwise, Amazon S3 fails the request with the HTTP status code 400 Bad Request. For more information, see Checking object integrity in the Amazon S3 User Guide.

If you provide an individual checksum, Amazon S3 ignores any provided ChecksumAlgorithm parameter.

content_md5: Option<ContentMD5>

The Base64 encoded 128-bit MD5 digest of the data. You must use this header as a message integrity check to verify that the request body was not corrupted in transit. For more information, see RFC 1864.

For requests made using the Amazon Web Services Command Line Interface (CLI) or Amazon Web Services SDKs, this field is calculated automatically.

expected_bucket_owner: Option<AccountId>

The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code 403 Forbidden (access denied).

tagging: Tagging

Container for the TagSet and Tag elements.

Implementations