Struct s3s::dto::PutObjectLockConfigurationInput
source · pub struct PutObjectLockConfigurationInput {
pub bucket: BucketName,
pub checksum_algorithm: Option<ChecksumAlgorithm>,
pub content_md5: Option<ContentMD5>,
pub expected_bucket_owner: Option<AccountId>,
pub object_lock_configuration: Option<ObjectLockConfiguration>,
pub request_payer: Option<RequestPayer>,
pub token: Option<ObjectLockToken>,
}Fields
bucket: BucketNameThe bucket whose Object Lock configuration you want to create or replace.
checksum_algorithm: Option<ChecksumAlgorithm>Indicates the algorithm used to create the checksum for the object when using the SDK. This header will not provide any
additional functionality if not using the SDK. When sending this header, there must be a corresponding x-amz-checksum or
x-amz-trailer header sent. Otherwise, Amazon S3 fails the request with the HTTP status code 400 Bad Request. For more
information, see Checking object integrity in
the Amazon S3 User Guide.
If you provide an individual checksum, Amazon S3 ignores any provided
ChecksumAlgorithm parameter.
content_md5: Option<ContentMD5>The MD5 hash for the request body.
For requests made using the Amazon Web Services Command Line Interface (CLI) or Amazon Web Services SDKs, this field is calculated automatically.
expected_bucket_owner: Option<AccountId>The account ID of the expected bucket owner. If the bucket is owned by a different account, the request fails with the HTTP status code 403 Forbidden (access denied).
object_lock_configuration: Option<ObjectLockConfiguration>The Object Lock configuration that you want to apply to the specified bucket.
request_payer: Option<RequestPayer>token: Option<ObjectLockToken>A token to allow Object Lock to be enabled for an existing bucket.