pub struct ReplicationTime {
pub status: ReplicationTimeStatus,
pub time: ReplicationTimeValue,
}Expand description
A container specifying S3 Replication Time Control (S3 RTC) related information, including whether S3 RTC is
enabled and the time when all objects and operations on objects must be replicated. Must be
specified together with a Metrics block.
Fields
status: ReplicationTimeStatusSpecifies whether the replication time is enabled.
time: ReplicationTimeValueA container specifying the time by which replication should be complete for all objects and operations on objects.