SelectObjectContentRequest

Struct SelectObjectContentRequest 

pub struct SelectObjectContentRequest {
    pub expression: Expression,
    pub expression_type: ExpressionType,
    pub input_serialization: InputSerialization,
    pub output_serialization: OutputSerialization,
    pub request_progress: Option<RequestProgress>,
    pub scan_range: Option<ScanRange>,
}
Learn Amazon S3 Select is no longer available to new customers. Existing customers of Amazon S3 Select can continue to use the feature as usual. Learn more

Request to filter the contents of an Amazon S3 object based on a simple Structured Query Language (SQL) statement. In the request, along with the SQL expression, you must specify a data serialization format (JSON or CSV) of the object. Amazon S3 uses this to parse object data into records. It returns only records that match the specified SQL expression. You must also specify the data serialization format for the response. For more information, see S3Select API Documentation.

Fields

expression: Expression

The expression that is used to query the object.

expression_type: ExpressionType

The type of the provided expression (for example, SQL).

input_serialization: InputSerialization

Describes the format of the data in the object that is being queried.

output_serialization: OutputSerialization

Describes the format of the data that you want Amazon S3 to return in response.

request_progress: Option<RequestProgress>

Specifies if periodic request progress information should be enabled.

scan_range: Option<ScanRange>

Specifies the byte range of the object to get the records from. A record is processed when its first byte is contained by the range. This parameter is optional, but when specified, it must not be empty. See RFC 2616, Section 14.35.1 about how to specify the start and end of the range.

ScanRangemay be used in the following ways:

  • 50100 - process only the records starting between the bytes 50 and 100 (inclusive, counting from zero)

  • 50 - process only the records starting after the byte 50

  • 50 - process only the records within the last 50 bytes of the file.