pub struct TopicConfiguration {
pub events: EventList,
pub filter: Option<NotificationConfigurationFilter>,
pub id: Option<NotificationId>,
pub topic_arn: TopicArn,
}Expand description
A container for specifying the configuration for publication of messages to an Amazon Simple Notification Service (Amazon SNS) topic when Amazon S3 detects specified events.
Fields
events: EventListThe Amazon S3 bucket event about which to send notifications. For more information, see Supported Event Types in the Amazon S3 User Guide.
filter: Option<NotificationConfigurationFilter>id: Option<NotificationId>topic_arn: TopicArnThe Amazon Resource Name (ARN) of the Amazon SNS topic to which Amazon S3 publishes a message when it detects events of the specified type.