pub struct S3Response<T> {
pub output: T,
pub status: Option<StatusCode>,
pub headers: HeaderMap,
pub extensions: Extensions,
}Expand description
S3 response
Fields
output: TS3 operation output
status: Option<StatusCode>HTTP status code. This field overrides the status code implied by the output.
headers: HeaderMapHTTP headers. This field overrides the headers implied by the output.
extensions: ExtensionsResponse extensions. This is used to pass custom data between middlewares.
Implementations
Sourceimpl<T> S3Response<T>
impl<T> S3Response<T>
Sourcepub fn with_status(output: T, status: StatusCode) -> Self
pub fn with_status(output: T, status: StatusCode) -> Self
Create a new S3 response with the given output and status code.
Sourcepub fn with_headers(output: T, headers: HeaderMap) -> Self
pub fn with_headers(output: T, headers: HeaderMap) -> Self
Create a new S3 response with the given output and headers.
Sourcepub fn map_output<U>(self, f: impl FnOnce(T) -> U) -> S3Response<U>
pub fn map_output<U>(self, f: impl FnOnce(T) -> U) -> S3Response<U>
Map the output of the response to a new type.