pub struct AssumedRoleUser {
pub arn: ArnType,
pub assumed_role_id: AssumedRoleIdType,
}Expand description
The identifiers for the temporary security credentials that the operation returns.
Fields
arn: ArnTypeThe ARN of the temporary security credentials that are returned from the AssumeRole action. For more information about ARNs and how to use them in policies, see IAM Identifiers in the IAM User Guide.
assumed_role_id: AssumedRoleIdTypeA unique identifier that contains the role ID and the role session name of the role that is being assumed. The role ID is generated by Amazon Web Services when the role is created.