pub struct GetObjectTaggingInput {
pub bucket: BucketName,
pub expected_bucket_owner: Option<AccountId>,
pub key: ObjectKey,
pub request_payer: Option<RequestPayer>,
pub version_id: Option<ObjectVersionId>,
}Fields
bucket: BucketNameThe bucket name containing the object for which to get the tagging information.
Access points - When you use this action with an access point, you must provide the alias of the access point in place of the bucket name or specify the access point ARN. When using the access point ARN, you must direct requests to the access point hostname. The access point hostname takes the form AccessPointName-AccountId.s3-accesspoint.Region.amazonaws.com. When using this action with an access point through the Amazon Web Services SDKs, you provide the access point ARN in place of the bucket name. For more information about access point ARNs, see Using access points in the Amazon S3 User Guide.
S3 on Outposts - When you use this action with S3 on Outposts, you must direct requests to the S3 on Outposts hostname. The S3 on Outposts hostname takes the
form
AccessPointName-AccountId.outpostID.s3-outposts.Region.amazonaws.com. When you use this action with S3 on Outposts, the destination bucket must be the Outposts access point ARN or the access point alias. For more information about S3 on Outposts, see What is S3 on Outposts? in the Amazon S3 User Guide.
expected_bucket_owner: Option<AccountId>The account ID of the expected bucket owner. If the account ID that you provide does not match the actual owner of the bucket, the request fails with the HTTP status code 403 Forbidden (access denied).
key: ObjectKeyObject key for which to get the tagging information.
request_payer: Option<RequestPayer>version_id: Option<ObjectVersionId>The versionId of the object for which to get the tagging information.
Implementations
Sourceimpl GetObjectTaggingInput
impl GetObjectTaggingInput
pub fn builder() -> GetObjectTaggingInputBuilder