pub struct InvalidObjectState {
pub access_tier: Option<IntelligentTieringAccessTier>,
pub storage_class: Option<StorageClass>,
}Expand description
Object is archived and inaccessible until restored.
If the object you are retrieving is stored in the S3 Glacier Flexible Retrieval storage
class, the S3 Glacier Deep Archive storage class, the S3 Intelligent-Tiering Archive Access
tier, or the S3 Intelligent-Tiering Deep Archive Access tier, before you can retrieve the object you
must first restore a copy using RestoreObject. Otherwise, this
operation returns an InvalidObjectState error. For information about restoring
archived objects, see Restoring Archived Objects in
the Amazon S3 User Guide.
Fields
access_tier: Option<IntelligentTieringAccessTier>storage_class: Option<StorageClass>Trait Implementations
Sourceimpl Clone for InvalidObjectState
impl Clone for InvalidObjectState
Sourcefn clone(&self) -> InvalidObjectState
fn clone(&self) -> InvalidObjectState
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for InvalidObjectState
impl Debug for InvalidObjectState
Sourceimpl Default for InvalidObjectState
impl Default for InvalidObjectState
Sourcefn default() -> InvalidObjectState
fn default() -> InvalidObjectState
Returns the “default value” for a type. Read more
Sourceimpl DtoExt for InvalidObjectState
impl DtoExt for InvalidObjectState
Sourcefn ignore_empty_strings(&mut self)
fn ignore_empty_strings(&mut self)
Modifies all empty string fields from
Some("") to NoneSourceimpl PartialEq for InvalidObjectState
impl PartialEq for InvalidObjectState
Sourcefn eq(&self, other: &InvalidObjectState) -> bool
fn eq(&self, other: &InvalidObjectState) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for InvalidObjectState