Struct s3s::dto::ObjectLockConfiguration
source · pub struct ObjectLockConfiguration {
pub object_lock_enabled: Option<ObjectLockEnabled>,
pub rule: Option<ObjectLockRule>,
}Expand description
The container element for Object Lock configuration parameters.
Fields
object_lock_enabled: Option<ObjectLockEnabled>Indicates whether this bucket has an Object Lock configuration enabled.
Enable ObjectLockEnabled when you apply ObjectLockConfiguration
to a bucket.
rule: Option<ObjectLockRule>Specifies the Object Lock rule for the specified object. Enable the this rule when you apply
ObjectLockConfiguration to a bucket. Bucket settings require both a mode and a period.
The period can be either Days or Years but you must select one.
You cannot specify Days and Years at the same time.