pub struct ObjectVersion {
pub checksum_algorithm: Option<ChecksumAlgorithmList>,
pub checksum_type: Option<ChecksumType>,
pub e_tag: Option<ETag>,
pub is_latest: Option<IsLatest>,
pub key: Option<ObjectKey>,
pub last_modified: Option<LastModified>,
pub owner: Option<Owner>,
pub restore_status: Option<RestoreStatus>,
pub size: Option<Size>,
pub storage_class: Option<ObjectVersionStorageClass>,
pub version_id: Option<ObjectVersionId>,
}Expand description
The version of an object.
Fields
checksum_algorithm: Option<ChecksumAlgorithmList>The algorithm that was used to create a checksum of the object.
checksum_type: Option<ChecksumType>The checksum type that is used to calculate the object’s checksum value. For more information, see Checking object integrity in the Amazon S3 User Guide.
e_tag: Option<ETag>The entity tag is an MD5 hash of that version of the object.
is_latest: Option<IsLatest>Specifies whether the object is (true) or is not (false) the latest version of an object.
key: Option<ObjectKey>The object key.
last_modified: Option<LastModified>Date and time when the object was last modified.
owner: Option<Owner>Specifies the owner of the object.
restore_status: Option<RestoreStatus>Specifies the restoration status of an object. Objects in certain storage classes must be restored before they can be retrieved. For more information about these storage classes and how to work with archived objects, see Working with archived objects in the Amazon S3 User Guide.
size: Option<Size>Size in bytes of the object.
storage_class: Option<ObjectVersionStorageClass>The class of storage used to store the object.
version_id: Option<ObjectVersionId>Version ID of an object.